/**
 * LinkedSelection ist ein Klasse zur Steuerung dynamisch verketteter Auswahllisten
 * @param inputSelects ein Array mit den IDs der Auswahllisten in hierarchischer Reihenfolge
 *						Bsp: [ 'select1', 'select2', 'select3' ]
 * @param callback Funktion, welche beim Abschlieen (und ndern) der Auswahl aufgerufen werden soll
 * @param data das Daten-Objekt in JSON
 *						Bsp: { 'select1':['wert1','text1'], 'select2':['wert5','text5'] }
 **/
function LinkedSelection( inputSelects, callback, data, startArray, firstCall )
{
	var self = this;				/* um aus EventHandlern auf diese Instanz zugreifen zu knnen */
	var selects = new Array();		/* Liste der verketteten Auswahllisten */

	/**
	 * Die Funktion changeHandler wird dem onchange-Handler jeder Auswahlliste zugewiesen.
	 * Wenn eine gltige Auswahl getroffen wurde, soll entweder die als nchste
	 * Auswahlliste (nextSelect) bekannte Auswahlliste mit Daten befllt werden,
	 * oder die Callback-Funktion ausgefhrt werden.
	 **/
	var changeHandler = function()
	{
		//if(startArray.length>0)
		//	alert(eval(startArray));
		if((startArray.length>0)&&(firstCall)&&(this.id=="riemen")){
			this.value=startArray[0];
		}	
		
		var value = this.selectedValue();
		
		// Abbrechen, wenn ein Dummy-Wert ausgewhlt wurde
		if( value == '--' )
		{
			
			if( this.selectID < selects.length ){
				alert("dummy");
				selects[ this.selectID +1 ].replaceOptions( new Array() );
			}	
			return;
		}

		if( typeof(this.nextSelect) == 'object' )
		{
			/*
			 * nextSelect ist eine Auswahlliste
			 */
			// Wenn keine Daten zur gemachten Auswahl zur Verfgung stehen,
			// mssen wir sicherstellen, dass wir auf keine nicht vorhandenen Objekte zugreifen.
			if( !data[ this.nextSelect.id ][ value ] )
			{
				if( !data[ this.nextSelect.id ] )
					data[ this.nextSelect.id ] = {};

				data[ this.nextSelect.id ][ value ] = new Array();
			}

			// Neue Optionen in der nchsten Auswahlliste setzen
			
			//Eintragen der default Anzeige 	
			
			this.nextSelect.replaceOptions( data[ this.nextSelect.id ][ value ] );
			
			//Display given selection
			if((startArray.length>0)&&(firstCall)&&(this.id=="riemen")){
				this.nextSelect.value=startArray[1];
			}
				
			if(typeof(this.nextSelect.nextSelect) == 'object'){
				var nextValue=data[ this.nextSelect.id ][ value ][0][0];
				
				//Display given selection
				if((startArray.length>0)&&(firstCall)&&(this.id=="riemen")){
					nextValue=startArray[1];
				}
				this.nextSelect.nextSelect.replaceOptions( data[this.nextSelect.nextSelect.id][ nextValue ] );
				
				//Display given selection
				if((startArray.length>0)&&(firstCall)&&(this.id=="riemen")){
					this.nextSelect.nextSelect.value=startArray[2];
				}
				
				if(typeof(this.nextSelect.nextSelect.nextSelect) == 'object'){
					var nextNextValue=data[this.nextSelect.nextSelect.id][ nextValue ][0][0];
					
					//Display given selection
					if((startArray.length>0)&&(firstCall)&&(this.id=="riemen")){
						nextNextValue=startArray[2];
					}
					
					this.nextSelect.nextSelect.nextSelect.replaceOptions( data[this.nextSelect.nextSelect.nextSelect.id][ nextNextValue ] );
					
					//Display given selection 
					if((startArray.length>0)&&(firstCall)&&(this.id=="riemen")){
						this.nextSelect.nextSelect.nextSelect.value=startArray[3];
					}
				}
			}
			
			// Wenn die Auswahlstrecke nicht beendet ist, muss die Callback-Funktion
			// dennoch aufgerufen werden, damit entsprechend auf nderungen
			// reagiert werden kann.
			var selected = new Array();
			for( var i = 0; i < selects.length; i++ )
			{
				selected.push( { 'id' : selects[i].id,
								 'value': selects[i].selectedValue(),
								 'text' : selects[i].selectedText() } );
			}
			
			firstCall=false;
			callback( selected );
		}
		else
		{
			/*
			 * Die Auswahlstrecke ist absolviert
			 */

			// Wahlen der einzelnen Listen in ein Array schreiben um
			// dieses an die Callback-Funktion zu bergeben.
			var selected = new Array();
			for( var i = 0; i < selects.length; i++ )
			{
				selected.push( { 'id' : selects[i].id,
								 'value': selects[i].selectedValue(),
								 'text' : selects[i].selectedText() } );
			}
			callback( selected );
		}
	};

	/**
	 * replaceOptions ersetzt die aktuellen Optionen der Auswahlliste durch
	 * die im Array newOptions gelieferten Daten. Wenn ein leeres Array bergeben
	 * wird, wird die default-Option "--" gesetzt.
	 * @param newOptions ein Array mit den neuen Optionen
	 *					  Bsp: [ ['value1','text1'], ['value2','text2'], ]
	 **/
	var replaceOptions = function( newOptions )
	{
		/*
		 * Diese Funktion setzt bewusst DOM-Methoden ein und verzichtet
		 * auf die vom Options-Objekt gegebenen Mglichkeiten.
		 */
				
		// alte Optionen der Auswahlliste lschen
		var opts = this.getElementsByTagName( 'option' );
		while( opts.length > 0 )
			this.removeChild( opts[0] );
		
		// wenn keine neuen Optionen bergeben wurden, default-Option setzen
		// andernfalls "Bitte whlen" voranstellen
		if( newOptions.length == 0){
			this.addOption( '--', '------' );
		}
		else{
		}

		// neue Optionen in die Auswahlliste schreiben
		for( var i = 0; i < newOptions.length; i++ ){
			
			//Hier Text nderung!!! 
			if (newOptions[i][1]=="Custom"){
			//alert(newOptions[i][1]);
			//alert(languageRes[lang]["widthTxt"]);
				this.addOption( newOptions[i][0], languageRes[lang]["widthTxt"] );
			}
			else	
				this.addOption( newOptions[i][0], newOptions[i][1] );
		}
	};

	/*
	 * Fgt der Auswahlliste eine neue Option hinzu
	 * @param value Wert der neuen Option
	 * @param text Name der neuen Option
	 */
	var addOption = function( value, text )
	{
		var opt = document.createElement( 'option' );
		opt.value = value;
		opt.appendChild( document.createTextNode( text ) );
		this.appendChild( opt );
	};

	/**
	 * holt den Wert der aktuell gewhlten Option
	 * @returns den Value der aktuell gewhlten Option
	 **/
	var selectedValue = function()
	{
		return this.options[ this.selectedIndex ].value;
	};

	/**
	 * holt den Text (Name) der aktuell gewhlten Option
	 * @returns den Text der aktuell gewhlten Option
	 **/
	var selectedText = function()
	{
		return this.options[ this.selectedIndex ].text;
	};

	/**
	 * Selektiere die Option mit dem Wert value, wenn keine Option mit dem Wert
	 * value existiert, wird die Auswahl nicht gendert.
	 * @param value der Wert den eine Option haben muss, um ausgewhlt zu werden.
	 **/
	var selectByValue = function( value )
	{
		for( var i = 0; i < this.options.length; i++ )
		{
			if( this.options[i].value == value )
				this.selectedIndex = i;
		}
	}

	/**
	 * Initialisiere den Manager fr verkettete Auswahllisten.
	 * Findet Auswahllisten anhand der (per inputSelects) bekannten IDs.
	 * Bestckt die Auswahllisten mit den ntigen Funktionen und Event-Handlern
	 **/
	this.init = function()
	{
		// bestcke bestehende selects
		for( var i = 0; i < inputSelects.length; i++ )
		{
			var t = document.getElementById( inputSelects[i] );

			// ignoriere falsche IDs
			if(!t)
				continue;

			// neue Funktionen und Event-Handler zuweisen und in selects registrieren
			t.replaceOptions = replaceOptions;
			t.addOption = addOption;
			t.selectedValue = selectedValue;
			t.selectedText = selectedText;
			t.selectByValue = selectByValue;
			t.selectID = selects.length;
			t.onchange = changeHandler;
			selects.push( t );

			// registriere Auswahlliste als nextSelect bei der vorhergehenden
			if( selects.length > 1 )
				selects[ selects.length-2 ].nextSelect = t;
		}
	};

	// initialisieren!
	this.init();
}